@@ -1,7 +1,5 @@
 package Getopt::Complete::Cache;
 
-our $VERSION = $Getopt::Complete::VERSION;
-
 use strict;
 use warnings;
 
@@ -66,14 +64,14 @@ sub import {
     
     $cache_path = $file if ($file);
     
-    if ( -f $cache_path && -s $cache_path) {
+    if ($cache_path and -e $cache_path) {
         my $fh;
         open($fh, $cache_path);
         if ($fh) {
             my $src = join('', <$fh>);
             require Getopt::Complete;
             my $spec = eval $src;
-            if (@$spec) {
+            if ($spec) {
                 Getopt::Complete->import(@$spec);
             }
         }
@@ -199,10 +197,6 @@ sub generate {
 
 Getopt::Complete::Cache - cache options next-to the command they apply-to
 
-=head1 VERSION
-
-This document describes Getopt::Complete::Cache 0.23.
-
 =head1 SYNOPSIS
 
 Presuming MyApp.pm isa Command, and "myapp" is an executable like:
